@@ -13,6 +13,13 @@ class Perturbator(ABC):
     In order to create your own perturbator, you should create a derived class that implements the perturbate method.
     The perturbate method should add the average effect in the desired way and return the dataframe with the extra average effect,
     without affecting the initial dataframe. Keep in mind to use `df = df.copy()` in the first line of the perturbate method.
+
+    Arguments:
+        average_effect: The average effect of the treatment
+        treatment: name of the treatment to use as the treated group
+        treatment_col: The name of the column that contains the treatment
+        treatment: name of the treatment to use as the treated group
+
     """
 
     def __init__(
@@ -22,13 +29,6 @@ class Perturbator(ABC):
         treatment_col: str = "treatment",
         treatment: str = "B",
     ):
-        """
-        Arguments:
-            average_effect: The average effect of the treatment
-            treatment: name of the treatment to use as the treated group
-            treatment_col: The name of the column that contains the treatment
-            treatment: name of the treatment to use as the treated group
-        """
         self.average_effect = average_effect
         self.target_col = target_col
         self.treatment_col = treatment_col
@@ -52,7 +52,9 @@ class Perturbator(ABC):
 
 
 class UniformPerturbator(Perturbator):
-    """UniformPerturbator is a Perturbator that adds a uniform effect to the target column of the treated instances."""
+    """
+    UniformPerturbator is a Perturbator that adds a uniform effect to the target column of the treated instances.
+    """
 
     def perturbate(self, df: pd.DataFrame) -> pd.DataFrame:
         """
@@ -76,7 +78,8 @@ class UniformPerturbator(Perturbator):
 class BinaryPerturbator(Perturbator):
     """
     BinaryPerturbator is a Perturbator that adds is used to deal with binary outcome variables.
-    It randomly selects some treated instances and flips their outcome from 0 to 1 or 1 to 0, depending on the effect being positive or negative"""
+    It randomly selects some treated instances and flips their outcome from 0 to 1 or 1 to 0, depending on the effect being positive or negative
+    """
 
     def _sample_max(self, df: pd.DataFrame, n: int) -> pd.DataFrame:
         """Like sample without replacement,
